@@ -1,11 +1,24 @@
+#include <Python.h>
+
+#include <iostream>
+
 #include "classes.hpp"
 #include "methods.hpp"
-#include <Python.h>
 
 #if PY_VERSION_HEX < 0x03000000
 PyMODINIT_FUNC init_bindings(void)
 {
-    (void)Py_InitModule("_bindings", scorepy::getMethodTable());
+    PyObject* m;
+#if SCOREPY_ENABLE_CINSTRUMENTER
+    static PyTypeObject ctracerType = scorepy::getCInstrumenterType();
+    if (PyType_Ready(&ctracerType) < 0)
+        return;
+#endif
+    m = Py_InitModule("_bindings", scorepy::getMethodTable());
+#if SCOREPY_ENABLE_CINSTRUMENTER
+    Py_INCREF(&ctracerType);
+    PyModule_AddObject(m, "CInstrumenter", (PyObject*)&ctracerType);
+#endif
 }
 #else /*python 3*/
 static struct PyModuleDef scorepmodule = { PyModuleDef_HEAD_INIT, "_bindings", /* name of module */
